==> Rare-0.9.0.1.tar.gz: Rare-0.9.0.1/README.md <==
# Rare

## A frontend for legendary, the open source Epic Games Launcher alternative

Rare is currently considered beta software and in no way feature-complete. You will probably run into issues, so it is recommend to make a backup. If you have features you want to have in this app, create an issue on github, contact me on Discord (Dummerle#7419) or build it yourself. Please report bugs so I can fix them.
I work on a new and better version, with better style and better ui. If you are a designer and want to contribute, please contact me. You can test it in the branch "new-style", but it has just the basic features


### Requirements

- requests,
- pillow
- pyqt5
- legendary-gl
- notify-py
- QtAwesome

## Installation

### Installation via pip (recommend)

Execute *pip install Rare* for all users Or *pip install Rare --user* for only one user

### Windows Simple

Download Rare.exe and place it somewhere in PATH

**Note**
Using the exe-file could cause an error with the stylesheets

## Linux

- For Arch Linux is an AUR package available: [rare-git](https://aur.archlinux.org/packages/rare-git)
- Other distributions have to install it with pip or clone the repo and install it manually: *python3 setup.py install*

## Implemented

- Launch, install and uninstall games
- Authentication(Import from existing installation and via Browser)
- In-app Browser to buy games
- Settings (Legendary and games)
- Translations (English and German)

## Planned
- Sync Cloud Saves
- Download Progressbar
- Offline mode
- More Translations

## Images

![alt text](https://github.com/Dummerle/Rare/blob/main/Screenshots/Rare.png?raw=true)
![alt text](https://github.com/Dummerle/Rare/blob/main/Screenshots/GameInfo.png?raw=true)
![alt text](https://github.com/Dummerle/Rare/blob/main/Screenshots/RareSettings.png?raw=true)

==> Rare-0.9.5.1.tar.gz: Rare-0.9.5.1/README.md <==
# Rare

## A frontend for legendary, the open source Epic Games Launcher alternative

Rare is currently considered beta software and in no way feature-complete. You will probably run into issues, so it is
recommend to make a backup. If you have features you want to have in this app, create an issue on github, contact me on
Discord (Dummerle#7419) or build it yourself. Please report bugs so I can fix them.

### Requirements

- requests,
- pillow
- pyqt5
- notify-py
- QtAwesome

## Installation

### Installation via pip (recommend)

Execute *pip install Rare* for all users Or *pip install Rare --user* for only one user

**Note**: On Linux must be /home/user/.local/bin in PATH

### Windows Simple

Download Rare.exe and place it somewhere in PATH

**Note**
Using the exe file could cause errors

## Linux

- For Arch Linux is an AUR package available: [rare-git](https://aur.archlinux.org/packages/rare-git) or [rare](https://aur.archlinux.org/packages/rare)
- Other distributions have to install it with pip or clone the repo and install it manually: *python3 setup.py install*

## Implemented

- Launch, install and uninstall games
- Authentication(Import from existing installation and via Browser)
- Download progress bar
- Settings (Legendary and games)
- Sync Cloud Saves
- Translations (English and German)

## Planned

- Offline mode
- More Translations (Need help)

## Images

![alt text](https://github.com/Dummerle/Rare/blob/main/Screenshots/Rare.png?raw=true)
![alt text](https://github.com/Dummerle/Rare/blob/main/Screenshots/GameInfo.png?raw=true)
![alt text](https://github.com/Dummerle/Rare/blob/main/Screenshots/RareSettings.png?raw=true)
